@@ -1,33 +1,12 @@
 # -*- Mode: perl -*-
-#
-# $Id: Long.pm,v 1.1.1.1 2004/09/22 17:32:58 coppit Exp $
-#
-#  Copyright (c) 2000-2001, Raphael Manfredi
-#  
-#  You may redistribute only under the terms of the Artistic License,
-#  as specified in the README file that comes with the distribution.
-#
-# HISTORY
-# $Log: Long.pm,v $
-# Revision 1.1.1.1  2004/09/22 17:32:58  coppit
-# initial import
-#
-# Revision 0.1.1.1  2001/03/20 10:33:44  ram
-# patch3: changed interface of all getargs() routines
-# patch3: added mention of similar module Params::Validate
-#
-# Revision 0.1  2001/03/01 18:37:19  ram
-# Baseline for first alpha release.
-#
-# $EndLog$
-#
 
 use strict;
+use 5.005;
 
 package Getargs::Long;
 
 use vars qw($VERSION @ISA @EXPORT);
-$VERSION = sprintf "%d.%02d%02d", q/1.10.0/ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d%02d", q/1.10.3/ =~ /(\d+)/g;
 
 BEGIN
 {
@@ -1094,13 +1073,22 @@ See L<Params::Validate> for another take at parameter validation.  It is
 a completely independant module, developped by Dave Rolsky, which may
 also interest you.  Its interface and purpose are different though.
 
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
+
 =head1 AUTHOR
 
-Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>
+The original code (written before September 15, 2004) was written by 
+Raphael Manfredi E<lt>Raphael_Manfredi@pobox.comE<gt>.
+
+Maintenance of this module is now being done by David Coppit
+E<lt>david@coppit.orgE<gt>.
 
 =head1 SEE ALSO
 
-Log::Agent(3), Params::Validate(3)
+L<Log::Agent>, L<Params::Validate>
 
 =cut
 
